pub struct PlainDateTime {
time: Time,
date: Date,
}Expand description
Combined date and time.
Fields
time: Timedate: DateImplementations
Sourceimpl PlainDateTime
impl PlainDateTime
Sourcepub const MIN: Self
pub const MIN: Self
The smallest value that can be represented by PlainDateTime.
Depending on large-dates feature flag, value of this constant may vary.
- With
large-datesdisabled it is equal to-9999-01-01 00:00:00.0 - With
large-datesenabled it is equal to-999999-01-01 00:00:00.0
Sourcepub const MAX: Self
pub const MAX: Self
The largest value that can be represented by PlainDateTime.
Depending on large-dates feature flag, value of this constant may vary.
- With
large-datesdisabled it is equal to9999-12-31 23:59:59.999_999_999 - With
large-datesenabled it is equal to999999-12-31 23:59:59.999_999_999
Sourceconst fn as_i128(self) -> i128
const fn as_i128(self) -> i128
Provide a representation of PlainDateTime as a i128. This value can be used for
equality, hashing, and ordering.
Note: This value is explicitly signed, so do not cast this to or treat this as an unsigned integer. Doing so will lead to incorrect results for values with differing signs.
Sourcepub const fn iso_week(self) -> u8
pub const fn iso_week(self) -> u8
Get the ISO week number.
The returned value will always be in the range 1..=53.
Sourcepub const fn sunday_based_week(self) -> u8
pub const fn sunday_based_week(self) -> u8
Get the week number where week 1 begins on the first Sunday.
The returned value will always be in the range 0..=53.
Sourcepub const fn monday_based_week(self) -> u8
pub const fn monday_based_week(self) -> u8
Get the week number where week 1 begins on the first Monday.
The returned value will always be in the range 0..=53.
Sourcepub const fn to_calendar_date(self) -> (i32, Month, u8)
pub const fn to_calendar_date(self) -> (i32, Month, u8)
Sourcepub const fn to_ordinal_date(self) -> (i32, u16)
pub const fn to_ordinal_date(self) -> (i32, u16)
Sourcepub const fn to_iso_week_date(self) -> (i32, u8, Weekday)
pub const fn to_iso_week_date(self) -> (i32, u8, Weekday)
Get the ISO 8601 year, week number, and weekday.
assert_eq!(
datetime!(2019-01-01 0:00).to_iso_week_date(),
(2019, 1, Tuesday)
);
assert_eq!(
datetime!(2019-10-04 0:00).to_iso_week_date(),
(2019, 40, Friday)
);
assert_eq!(
datetime!(2020-01-01 0:00).to_iso_week_date(),
(2020, 1, Wednesday)
);
assert_eq!(
datetime!(2020-12-31 0:00).to_iso_week_date(),
(2020, 53, Thursday)
);
assert_eq!(
datetime!(2021-01-01 0:00).to_iso_week_date(),
(2020, 53, Friday)
);Sourcepub const fn weekday(self) -> Weekday
pub const fn weekday(self) -> Weekday
Get the weekday.
assert_eq!(datetime!(2019-01-01 0:00).weekday(), Tuesday);
assert_eq!(datetime!(2019-02-01 0:00).weekday(), Friday);
assert_eq!(datetime!(2019-03-01 0:00).weekday(), Friday);
assert_eq!(datetime!(2019-04-01 0:00).weekday(), Monday);
assert_eq!(datetime!(2019-05-01 0:00).weekday(), Wednesday);
assert_eq!(datetime!(2019-06-01 0:00).weekday(), Saturday);
assert_eq!(datetime!(2019-07-01 0:00).weekday(), Monday);
assert_eq!(datetime!(2019-08-01 0:00).weekday(), Thursday);
assert_eq!(datetime!(2019-09-01 0:00).weekday(), Sunday);
assert_eq!(datetime!(2019-10-01 0:00).weekday(), Tuesday);
assert_eq!(datetime!(2019-11-01 0:00).weekday(), Friday);
assert_eq!(datetime!(2019-12-01 0:00).weekday(), Sunday);Sourcepub const fn to_julian_day(self) -> i32
pub const fn to_julian_day(self) -> i32
Get the Julian day for the date. The time is not taken into account for this calculation.
Sourcepub const fn millisecond(self) -> u16
pub const fn millisecond(self) -> u16
Sourcepub const fn microsecond(self) -> u32
pub const fn microsecond(self) -> u32
Sourcepub const fn nanosecond(self) -> u32
pub const fn nanosecond(self) -> u32
Sourcepub const fn assume_offset(self, offset: UtcOffset) -> OffsetDateTime
pub const fn assume_offset(self, offset: UtcOffset) -> OffsetDateTime
Assuming that the existing PlainDateTime represents a moment in the provided
UtcOffset, return an OffsetDateTime.
Sourcepub const fn assume_utc(self) -> OffsetDateTime
pub const fn assume_utc(self) -> OffsetDateTime
Assuming that the existing PlainDateTime represents a moment in UTC, return an
OffsetDateTime.
Note: You may want a UtcDateTime instead, which can be obtained with the
PlainDateTime::as_utc method.
Sourcepub const fn as_utc(self) -> UtcDateTime
pub const fn as_utc(self) -> UtcDateTime
Assuming that the existing PlainDateTime represents a moment in UTC, return a
UtcDateTime.
Sourcepub const fn checked_add(self, duration: SignedDuration) -> Option<Self>
pub const fn checked_add(self, duration: SignedDuration) -> Option<Self>
Computes self + duration, returning None if an overflow occurred.
Sourcepub const fn checked_sub(self, duration: SignedDuration) -> Option<Self>
pub const fn checked_sub(self, duration: SignedDuration) -> Option<Self>
Computes self - duration, returning None if an overflow occurred.
Sourcepub const fn saturating_add(self, duration: SignedDuration) -> Self
pub const fn saturating_add(self, duration: SignedDuration) -> Self
Computes self + duration, saturating value on overflow.
Sourcepub const fn saturating_sub(self, duration: SignedDuration) -> Self
pub const fn saturating_sub(self, duration: SignedDuration) -> Self
Computes self - duration, saturating value on overflow.
Sourceimpl PlainDateTime
Methods that replace part of the PlainDateTime.
impl PlainDateTime
Methods that replace part of the PlainDateTime.
Sourcepub const fn replace_time(self, time: Time) -> Self
pub const fn replace_time(self, time: Time) -> Self
Sourcepub const fn replace_date(self, date: Date) -> Self
pub const fn replace_date(self, date: Date) -> Self
Sourcepub const fn replace_year(self, year: i32) -> Result<Self, ComponentRange>
pub const fn replace_year(self, year: i32) -> Result<Self, ComponentRange>
Replace the year. The month and day will be unchanged.
assert_eq!(
datetime!(2022-02-18 12:00).replace_year(2019),
Ok(datetime!(2019-02-18 12:00))
);
assert!(datetime!(2022-02-18 12:00).replace_year(-1_000_000_000).is_err()); // -1_000_000_000 isn't a valid year
assert!(datetime!(2022-02-18 12:00).replace_year(1_000_000_000).is_err()); // 1_000_000_000 isn't a valid yearSourcepub const fn replace_month(self, month: Month) -> Result<Self, ComponentRange>
pub const fn replace_month(self, month: Month) -> Result<Self, ComponentRange>
Sourcepub const fn replace_day(self, day: u8) -> Result<Self, ComponentRange>
pub const fn replace_day(self, day: u8) -> Result<Self, ComponentRange>
Replace the day of the month.
Sourcepub const fn replace_ordinal(self, ordinal: u16) -> Result<Self, ComponentRange>
pub const fn replace_ordinal(self, ordinal: u16) -> Result<Self, ComponentRange>
Replace the day of the year.
Sourcepub const fn truncate_to_day(self) -> Self
pub const fn truncate_to_day(self) -> Self
Sourcepub const fn replace_hour(self, hour: u8) -> Result<Self, ComponentRange>
pub const fn replace_hour(self, hour: u8) -> Result<Self, ComponentRange>
Sourcepub const fn truncate_to_hour(self) -> Self
pub const fn truncate_to_hour(self) -> Self
Sourcepub const fn replace_minute(self, minute: u8) -> Result<Self, ComponentRange>
pub const fn replace_minute(self, minute: u8) -> Result<Self, ComponentRange>
Sourcepub const fn truncate_to_minute(self) -> Self
pub const fn truncate_to_minute(self) -> Self
Sourcepub const fn replace_second(self, second: u8) -> Result<Self, ComponentRange>
pub const fn replace_second(self, second: u8) -> Result<Self, ComponentRange>
Sourcepub const fn truncate_to_second(self) -> Self
pub const fn truncate_to_second(self) -> Self
Sourcepub const fn replace_millisecond(
self,
millisecond: u16,
) -> Result<Self, ComponentRange>
pub const fn replace_millisecond( self, millisecond: u16, ) -> Result<Self, ComponentRange>
Sourcepub const fn truncate_to_millisecond(self) -> Self
pub const fn truncate_to_millisecond(self) -> Self
Sourcepub const fn replace_microsecond(
self,
microsecond: u32,
) -> Result<Self, ComponentRange>
pub const fn replace_microsecond( self, microsecond: u32, ) -> Result<Self, ComponentRange>
Replace the microseconds within the second.
Sourcepub const fn truncate_to_microsecond(self) -> Self
pub const fn truncate_to_microsecond(self) -> Self
Sourcepub const fn replace_nanosecond(
self,
nanosecond: u32,
) -> Result<Self, ComponentRange>
pub const fn replace_nanosecond( self, nanosecond: u32, ) -> Result<Self, ComponentRange>
Replace the nanoseconds within the second.
Sourceimpl PlainDateTime
impl PlainDateTime
Sourcepub fn format_into(
self,
output: &mut (impl Write + ?Sized),
format: &(impl Formattable + ?Sized),
) -> Result<usize, Format>
Available on crate feature formatting only.
pub fn format_into( self, output: &mut (impl Write + ?Sized), format: &(impl Formattable + ?Sized), ) -> Result<usize, Format>
formatting only.Format the PlainDateTime using the provided format ///
description.
Sourcepub fn format(
self,
format: &(impl Formattable + ?Sized),
) -> Result<String, Format>
Available on crate feature formatting only.
pub fn format( self, format: &(impl Formattable + ?Sized), ) -> Result<String, Format>
formatting only.Format the PlainDateTime using the provided format
description.
Sourceimpl PlainDateTime
impl PlainDateTime
Sourcepub fn parse(
input: &str,
description: &(impl Parsable + ?Sized),
) -> Result<Self, Parse>
Available on crate feature parsing only.
pub fn parse( input: &str, description: &(impl Parsable + ?Sized), ) -> Result<Self, Parse>
parsing only.Parse a PlainDateTime from the input using the provided format
description.
Sourcepub fn parse_with_defaults(
input: &[u8],
description: &(impl Parsable + ?Sized),
defaults: Parsed,
) -> Result<Self, Parse>
Available on crate feature parsing only.
pub fn parse_with_defaults( input: &[u8], description: &(impl Parsable + ?Sized), defaults: Parsed, ) -> Result<Self, Parse>
parsing only.Parse a PlainDateTime from the input using the provided format
description and default values.
Sourceimpl PlainDateTime
impl PlainDateTime
Sourcepub(crate) const DISPLAY_BUFFER_SIZE: usize
pub(crate) const DISPLAY_BUFFER_SIZE: usize
The maximum number of bytes that the fmt_into_buffer method will write, which is also used
for the Display implementation.
Sourcepub(crate) fn fmt_into_buffer(self, buf: &mut [MaybeUninit<u8>; 32]) -> usize
pub(crate) fn fmt_into_buffer(self, buf: &mut [MaybeUninit<u8>; 32]) -> usize
Format the PlainDateTime into the provided buffer, returning the number of bytes written.